==> veil-fabric-1.21-1.0.0.13-sources.jar: foundry/veil/mixin/client/shader/ProgramMixin.java <==
package foundry.veil.mixin.client.shader;

import foundry.veil.Veil;
import foundry.veil.impl.client.render.shader.SimpleShaderProcessor;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.ModifyArg;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.io.InputStream;
import java.util.List;
import net.minecraft.class_281;
import net.minecraft.class_2960;
import net.minecraft.class_5913;

@Mixin(class_281.class)
public class ProgramMixin {

    @Unique
    private static class_2960 veil$captureId;

    @Inject(method = "compileShaderInternal", at = @At("HEAD"))
    private static void veil$captureId(class_281.class_282 type, String name, InputStream stream, String pack, class_5913 glslPreprocessor, CallbackInfoReturnable<Integer> cir) {
        class_2960 loc = class_2960.method_60654(name);
        String s = "shaders/core/" + loc.method_12832() + type.method_1284();
        veil$captureId = class_2960.method_60655(loc.method_12836(), s);
    }

    @Inject(method = "compileShaderInternal", at = @At("RETURN"))
    private static void veil$clear(class_281.class_282 type, String name, InputStream stream, String pack, class_5913 glslPreprocessor, CallbackInfoReturnable<Integer> cir) {
        veil$captureId = null;
    }

    @ModifyArg(method = "compileShaderInternal", at = @At(value = "INVOKE", target = "Lcom/mojang/blaze3d/platform/GlStateManager;glShaderSource(ILjava/util/List;)V"), index = 1)
    private static List<String> veil$modifyVanillaShader(List<String> sourceLines) {
        try {
            StringBuilder source = new StringBuilder();
            for (String sourceLine : sourceLines) {
                source.append(sourceLine);
            }

            return List.of(SimpleShaderProcessor.modify(veil$captureId, source.toString()));
        } catch (Exception e) {
            Veil.LOGGER.error("Failed to modify vanilla source for shader: {}", veil$captureId, e);
        }
        return sourceLines;
    }
}

==> veil-fabric-1.21-1.0.0.19-sources.jar: foundry/veil/mixin/client/shader/ProgramMixin.java <==
package foundry.veil.mixin.client.shader;

import foundry.veil.Veil;
import foundry.veil.impl.client.render.shader.SimpleShaderProcessor;
import org.lwjgl.opengl.GL20C;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.ModifyArg;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.io.InputStream;
import java.util.List;
import net.minecraft.class_281;
import net.minecraft.class_2960;
import net.minecraft.class_5913;

import static org.lwjgl.opengl.GL20C.GL_FRAGMENT_SHADER;
import static org.lwjgl.opengl.GL20C.GL_VERTEX_SHADER;

@Mixin(class_281.class)
public class ProgramMixin {

    @Unique
    private static int veil$captureType;
    @Unique
    private static class_2960 veil$captureId;

    @Inject(method = "compileShaderInternal", at = @At("HEAD"))
    private static void veil$captureId(class_281.class_282 type, String name, InputStream stream, String pack, class_5913 glslPreprocessor, CallbackInfoReturnable<Integer> cir) {
        class_2960 loc = class_2960.method_60654(name);
        String s = "shaders/core/" + loc.method_12832() + type.method_1284();
        veil$captureType = type == class_281.class_282.field_1530 ? GL_VERTEX_SHADER : GL_FRAGMENT_SHADER;
        veil$captureId = class_2960.method_60655(loc.method_12836(), s);
    }

    @Inject(method = "compileShaderInternal", at = @At("RETURN"))
    private static void veil$clear(class_281.class_282 type, String name, InputStream stream, String pack, class_5913 glslPreprocessor, CallbackInfoReturnable<Integer> cir) {
        veil$captureId = null;
    }

    @ModifyArg(method = "compileShaderInternal", at = @At(value = "INVOKE", target = "Lcom/mojang/blaze3d/platform/GlStateManager;glShaderSource(ILjava/util/List;)V"), index = 1)
    private static List<String> veil$modifyVanillaShader(List<String> sourceLines) {
        try {
            StringBuilder source = new StringBuilder();
            for (String sourceLine : sourceLines) {
                source.append(sourceLine);
            }

            return List.of(SimpleShaderProcessor.modify(veil$captureId, veil$captureType, source.toString()));
        } catch (Exception e) {
            Veil.LOGGER.error("Failed to modify vanilla source for shader: {}", veil$captureId, e);
        }
        return sourceLines;
    }
}
